@@ -1,16 +1,35 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-""" Visualization utilities """
-
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
+"""Visualization utilities."""
 import math
 import os.path as op
-import numpy as np
-import nibabel as nb
 
 import matplotlib.pyplot as plt
-from matplotlib.gridspec import GridSpec
-from matplotlib.backends.backend_pdf import FigureCanvasPdf as FigureCanvas
+import nibabel as nb
+import numpy as np
 import seaborn as sns
+from matplotlib.backends.backend_pdf import FigureCanvasPdf as FigureCanvas
+from matplotlib.gridspec import GridSpec
 
 DEFAULT_DPI = 300
 DINA4_LANDSCAPE = (11.69, 8.27)
@@ -168,14 +187,19 @@ def plot_slice_tern(
 
 
 def plot_spikes(
-    in_file, in_fft, spikes_list, cols=3, labelfmt="t={0:.3f}s (z={1:d})", out_file=None
+    in_file,
+    in_fft,
+    spikes_list,
+    cols=3,
+    labelfmt="t={0:.3f}s (z={1:d})",
+    out_file=None,
 ):
     from mpl_toolkits.axes_grid1 import make_axes_locatable
 
     nii = nb.as_closest_canonical(nb.load(in_file))
-    fft = nb.load(in_fft).get_data()
+    fft = nb.load(in_fft).get_fdata()
 
-    data = nii.get_data()
+    data = nii.get_fdata()
     zooms = nii.header.get_zooms()[:2]
     tstep = nii.header.get_zooms()[-1]
     ntpoints = data.shape[-1]
@@ -257,7 +281,7 @@ def plot_mosaic(
 
     if isinstance(img, (str, bytes)):
         nii = nb.as_closest_canonical(nb.load(img))
-        img_data = nii.get_data()
+        img_data = nii.get_fdata()
         zooms = nii.header.get_zooms()
     else:
         img_data = img
@@ -274,7 +298,7 @@ def plot_mosaic(
         img_data = _bbox(img_data, mask_file)
 
     if bbox_mask_file is not None:
-        bbox_data = nb.as_closest_canonical(nb.load(bbox_mask_file)).get_data()
+        bbox_data = nb.as_closest_canonical(nb.load(bbox_mask_file)).get_fdata()
         img_data = _bbox(img_data, bbox_data)
 
     z_vals = np.array(list(range(0, img_data.shape[2])))
@@ -288,7 +312,8 @@ def plot_mosaic(
             z_vals = z_vals[rem:-rem]
         else:
             # img_data = img_data[..., 2 * rem:]
-            z_vals = z_vals[2 * rem:]
+            start_index = 2 * rem
+            z_vals = z_vals[start_index:]
 
     while len(z_vals) > zmax:
         # Discard one every two slices
@@ -301,7 +326,7 @@ def plot_mosaic(
         nrows += 1
 
     if overlay_mask:
-        overlay_data = nb.as_closest_canonical(nb.load(overlay_mask)).get_data()
+        overlay_data = nb.as_closest_canonical(nb.load(overlay_mask)).get_fdata()
 
     # create figures
     if fig is None:
@@ -514,9 +539,9 @@ def _get_mean_fd_distribution(fd_files, fd_radius):
 
 def _get_values_inside_a_mask(main_file, mask_file):
     main_nii = nb.load(main_file)
-    main_data = main_nii.get_data()
+    main_data = main_nii.get_fdata()
     nan_mask = np.logical_not(np.isnan(main_data))
-    mask = nb.load(mask_file).get_data() > 0
+    mask = nb.load(mask_file).get_fdata() > 0
 
     data = main_data[np.logical_and(nan_mask, mask)]
     return data
@@ -524,20 +549,34 @@ def _get_values_inside_a_mask(main_file, mask_file):
 
 def plot_segmentation(anat_file, segmentation, out_file, **kwargs):
     from nilearn.plotting import plot_anat
+    from nitransforms.io.afni import _dicom_real_to_card
 
     vmax = kwargs.get("vmax")
     vmin = kwargs.get("vmin")
 
+    anat_ras = nb.as_closest_canonical(nb.load(anat_file))
+    anat_ras_plumb = anat_ras.__class__(
+        anat_ras.dataobj,
+        _dicom_real_to_card(anat_ras.affine),
+        anat_ras.header
+    )
+
+    seg_ras = nb.as_closest_canonical(nb.load(segmentation))
+    seg_ras_plumb = seg_ras.__class__(
+        seg_ras.dataobj,
+        _dicom_real_to_card(seg_ras.affine),
+        seg_ras.header
+    )
+
     if kwargs.get("saturate", False):
-        vmax = np.percentile(nb.load(anat_file).get_data().reshape(-1), 70)
+        vmax = np.percentile(anat_ras.get_fdata().reshape(-1), 70)
 
     if vmax is None and vmin is None:
-
-        vmin = np.percentile(nb.load(anat_file).get_data().reshape(-1), 10)
-        vmax = np.percentile(nb.load(anat_file).get_data().reshape(-1), 99)
+        vmin = np.percentile(anat_ras.get_fdata().reshape(-1), 10)
+        vmax = np.percentile(anat_ras.get_fdata().reshape(-1), 99)
 
     disp = plot_anat(
-        anat_file,
+        anat_ras_plumb,
         display_mode=kwargs.get("display_mode", "ortho"),
         cut_coords=kwargs.get("cut_coords", 8),
         title=kwargs.get("title"),
@@ -545,7 +584,9 @@ def plot_segmentation(anat_file, segmentation, out_file, **kwargs):
         vmin=vmin,
     )
     disp.add_contours(
-        segmentation, levels=kwargs.get("levels", [1]), colors=kwargs.get("colors", "r")
+        seg_ras_plumb,
+        levels=kwargs.get("levels", [1]),
+        colors=kwargs.get("colors", "r"),
     )
     disp.savefig(out_file)
     disp.close()
@@ -553,10 +594,61 @@ def plot_segmentation(anat_file, segmentation, out_file, **kwargs):
     return out_file
 
 
+def plot_qi2(x_grid, ref_pdf, fit_pdf, ref_data, cutoff_idx, out_file=None):
+    fig, ax = plt.subplots()
+
+    ax.plot(
+        x_grid,
+        ref_pdf,
+        linewidth=2,
+        alpha=0.5,
+        label="background",
+        color="dodgerblue",
+    )
+
+    refmax = np.percentile(ref_data, 99.95)
+    x_max = x_grid[-1]
+
+    ax.hist(
+        ref_data,
+        40 * max(int(refmax / x_max), 1),
+        fc="dodgerblue",
+        histtype="stepfilled",
+        alpha=0.2,
+        density=True,
+    )
+    fit_pdf[fit_pdf > 1.0] = np.nan
+    ax.plot(
+        x_grid,
+        fit_pdf,
+        linewidth=2,
+        alpha=0.5,
+        label="chi2",
+        color="darkorange",
+    )
+
+    ylims = ax.get_ylim()
+    ax.axvline(
+        x_grid[-cutoff_idx],
+        ymax=ref_pdf[-cutoff_idx] / ylims[1],
+        color="dodgerblue",
+    )
+    plt.xlabel('Intensity within "hat" mask')
+    plt.ylabel("Frequency")
+    ax.set_xlim([0, x_max])
+    plt.legend()
+
+    if out_file is None:
+        out_file = op.abspath("qi2_plot.svg")
+
+    fig.savefig(out_file, bbox_inches="tight", pad_inches=0, dpi=300)
+    return out_file
+
+
 def _get_limits(nifti_file, only_plot_noise=False):
     if isinstance(nifti_file, str):
         nii = nb.as_closest_canonical(nb.load(nifti_file))
-        data = nii.get_data()
+        data = nii.get_fdata()
     else:
         data = nifti_file
 
